@@ -373,7 +373,8 @@ class Job():
             self,
             kind='Annotations',
             return_type="data",
-            wait_for_export_generation=True
+            wait_for_export_generation=True,
+            ann_is_complete=None    # Bool. None=='all', True=='complete' tasks only
     ):
         """
 
@@ -405,6 +406,7 @@ class Job():
             'file_comparison_mode': "latest",
             'directory_id': None,
             'masks': False,
+            'ann_is_complete': ann_is_complete,
             'return_type': return_type,
             'wait_for_export_generation': wait_for_export_generation
         }
